==> advanced-interface-switcher_0.3.9-6.tar.gz: advanced-interface-switcher-0.3.9/src/opt/maemo/usr/lib/hildon-desktop/advifswlib/core/maemo5.py <==
# -*- coding: utf-8 -*-

'''
Advanced Interface Switcher
2010-2011(c) Kirill Plyashkevich <ru.spirit@gmail.com>
System menu plugin class
'''

import gobject
import gtk

import hildon
from hildondesktop import StatusMenuItem
import dbus
from dbus.mainloop.glib import DBusGMainLoop

from advpowcommon.ui.Cachers import DITPixbufCacher
from advpowcommon.ui.Animation import DITPBCachedAnimator
from advpowcommon.ui.Config import ConfigUIMaemo5
from advpowcommon.ui.Gtk import *
from advpowcommon.ui.Notebook import NotebookMaemo5
from advifswlib.interfaces.GSM import GSMInterface
from advifswlib.interfaces.BT import BTInterface
from advifswlib.interfaces.WLAN import WLANInterface
import advifswlib.util.config as config
import advifswlib.util.locale as locale

class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):

  app_name = 'Advanced Interface Switcher'
  version = '0.3.9'
  dev_author = 'Kirill Plyashkevich'
  dev_email = 'ru.spirit@gmail.com'
  dev_years = '2010-2011'

  def __init__(self):

    StatusMenuItem.__init__(self)
    self.__lcl = locale.get()
    self.__interfaces = []
    self.__animation_images = {}
    self.__gtk_swr = get_gtk_stock_wrapper()
    self.__config = config.get()
    self.__config_ui = ConfigUIMaemo5()
    self.__sai_cacher = DITPixbufCacher(18)
    self.__sai_animator = DITPBCachedAnimator([], self.set_status_area_icon, 
                                              cacher=self.__sai_cacher, 
                                              time_out=1000)
    self.__m_loop = DBusGMainLoop()
    self.__bus = dbus.SystemBus(mainloop = self.__m_loop, private = True)

    ifaces = (GSMInterface, BTInterface, WLANInterface)#, FlightMode)
    self.__smi_box = gtk.Table(len(ifaces), 1, True)
    self.add(self.__smi_box)
    ilist = enumerate(ifaces)

    loaded_list = ''
    loaded_ifaces = 0
    for iface in ilist:
      try:
        self.__interfaces.append(iface[1](self.__bus, self.process_sai, 
                                          self.__show_settings_dialog))
        self.__smi_box.attach(self.__interfaces[iface[0]].get_button(), 
                              iface[0], iface[0]+1, 0, 1, 
                              gtk.EXPAND | gtk.FILL, 
                              gtk.SHRINK)
        loaded_ifaces += 1
        loaded_list = '%s\n%s' % (loaded_list, 
                                  self.__interfaces[iface[0]].get_name())
      except Exception, e:
        loaded_list = '%s\n%s\nError: %s\n' % (loaded_list, iface[1], e)
        pass
    print '\nLoaded (%s/%s)%s\n' % (loaded_ifaces, len(ifaces), loaded_list)
    self.show_all()
#    self.__show_settings_dialog()

  def __show_settings_dialog(self, button=None):
    self.__config.load()
    settings_dialog = gtk.Dialog(self.app_name, None, 
                                 gtk.DIALOG_MODAL | gtk.DIALOG_NO_SEPARATOR, 
                                 self.__config_ui.get_dialog_buttons())
    wpa = gtk.VBox()
    config_controls = {}
    config_keys = [key for key in self.__config.get_keys() 
                   if key.startswith('settings')]
    config_keys_controls = set(config_keys)
    for iface in self.__interfaces:
      iface_name = iface.get_name()
      iface_key = iface_name.lower()
      wpa.pack_start(gtk.Label('%s' % iface_name))
      iface_keys = set(key for key in config_keys_controls 
                       if key.startswith('settings/%s/' % (iface_key)))
      config_keys_controls -= iface_keys
      iface_keys = list(iface_keys)
      iface_keys.sort()
      for config_key in iface_keys:
        name, ck_type, value = self.__config.get_entry(config_key)
        config_options = self.__config.get_option(config_key)
        options = ()
        if config_options:
          options = zip(map(self.__lcl.get, config_options), config_options)
        config_control = self.__config_ui.create_control(self.__lcl.get(config_key.replace('settings/%s/' % (iface_key),'',1)), 
                                                         ck_type, 
                                                         (self.__lcl.get(str(value)), 
                                                          value), 
                                                         options)
        if config_control:
          config_controls[config_key] = config_control
          wpa.pack_start(config_control, False)
    if config_keys_controls:
      wpa.pack_start(gtk.Label(self.__lcl.get('settings-other')))
      for config_key in config_keys_controls:
        name, ck_type, value = self.__config.get_entry(config_key)
        config_options = self.__config.get_option(config_key)
        options = ()
        if config_options:
          options = zip(map(self.__lcl.get, config_options), config_options)
        config_control = self.__config_ui.create_control(self.__lcl.get(config_key), 
                                                         ck_type, 
                                                         (self.__lcl.get(str(value)), 
                                                          value), 
                                                         options)
        if config_control:
          config_controls[config_key] = config_control
          wpa.pack_start(config_control, False)
    about_page = gtk.VBox()
    about_page.pack_start(gtk.Label('%s %s' % (self.app_name, self.version)))
    about_page.pack_start(gtk.Label('%s%s %s <%s>' % (u'\u00A9', 
                                                      self.dev_years, 
                                                      self.dev_author, 
                                                      self.dev_email)))
    notebook = NotebookMaemo5()
    notebook.set_box(settings_dialog.vbox)
    notebook.append_pages(([[self.__gtk_swr.get_text(gtk.STOCK_PREFERENCES), 
                             wpa], 
                            [self.__gtk_swr.get_text(gtk.STOCK_ABOUT), 
                             about_page]]))
#    settings_dialog.vbox.set_size_request(-1, min(350, notebook.get_height()))
    settings_dialog.show_all()
    notebook.set_active(0)
    response = settings_dialog.run()

    if response == gtk.RESPONSE_OK:
      controls_keys = config_controls.keys()
      for config_key in config_keys:
        if config_key in controls_keys:
          name, ck_type, value = self.__config.get_entry(config_key)
          value = self.__config_ui.get_value(config_controls[config_key], 
                                             value, ck_type)
          self.__config.set_value(config_key, value)
      self.__config.save()
    settings_dialog.destroy()

  def process_sai(self, iname, image='', add=True):
    if add:
      try:
        self.__sai_animator.remove_image(self.__animation_images[iname])
      except:
        pass
      self.__animation_images[iname] = image
      self.__sai_animator.add_image(image)
    else:
      try:
        image = self.__animation_images[iname]
        self.__sai_animator.remove_image(image)
      except:
        pass

  def __set_sai(self, key):
    self.set_status_area_icon(self.__sai_cacher.get(key))

def get_hd_plugin_type(): return AdvancedInterfaceSwitcherMaemo5

==> advanced-interface-switcher_0.3.9-8.tar.gz: advanced-interface-switcher-0.3.9/src/opt/maemo/usr/lib/hildon-desktop/advifswlib/core/maemo5.py <==
# -*- coding: utf-8 -*-

'''
Advanced Interface Switcher
2010-2011(c) Kirill Plyashkevich <ru.spirit@gmail.com>
System menu plugin class
'''

import gobject
import gtk

import hildon
from hildondesktop import StatusMenuItem
import dbus
from dbus.mainloop.glib import DBusGMainLoop

from advpowcommon.ui.Cachers import DITPixbufCacher
from advpowcommon.ui.Animation import DITPBCachedAnimator
from advpowcommon.ui.Config import ConfigUIMaemo5
from advpowcommon.ui.Gtk import *
from advpowcommon.ui.Notebook import NotebookMaemo5
from advifswlib.interfaces.GSM import GSMInterface
from advifswlib.interfaces.BT import BTInterface
from advifswlib.interfaces.WLAN import WLANInterface
import advifswlib.util.config as config
import advifswlib.util.locale as locale

class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):

  app_name = 'Advanced Interface Switcher'
  version = '0.3.9'
  dev_author = 'Kirill Plyashkevich'
  dev_email = 'ru.spirit@gmail.com'
  dev_years = '2010-2011'

  def __init__(self):

    StatusMenuItem.__init__(self)
    self.__lcl = locale.get()
    self.__interfaces = []
    self.__animation_images = {}
    self.__gtk_swr = get_gtk_stock_wrapper()
    self.__config = config.get()
    self.__config_ui = ConfigUIMaemo5()
    self.__sai_cacher = DITPixbufCacher(18)
    self.__sai_animator = DITPBCachedAnimator([], self.set_status_area_icon, 
                                              cacher=self.__sai_cacher, 
                                              time_out=1000)
    self.__m_loop = DBusGMainLoop()
    self.__bus = dbus.SystemBus(mainloop = self.__m_loop, private = True)

    ifaces = (GSMInterface, BTInterface, WLANInterface)#, FlightMode)
    self.__smi_box = gtk.Table(len(ifaces), 1, True)
    self.add(self.__smi_box)
    ilist = enumerate(ifaces)

    loaded_list = ''
    loaded_ifaces = 0
    for iface in ilist:
      try:
        self.__interfaces.append(iface[1](self.__bus, self.process_sai, 
                                          self.__show_settings_dialog))
        self.__smi_box.attach(self.__interfaces[iface[0]].get_button(), 
                              iface[0], iface[0]+1, 0, 1, 
                              gtk.EXPAND | gtk.FILL, 
                              gtk.SHRINK)
        loaded_ifaces += 1
        loaded_list = '%s\n%s' % (loaded_list, 
                                  self.__interfaces[iface[0]].get_name())
      except Exception, e:
        loaded_list = '%s\n%s\nError: %s\n' % (loaded_list, iface[1], e)
        pass
    print '\nLoaded (%s/%s)%s\n' % (loaded_ifaces, len(ifaces), loaded_list)
    self.show_all()
#    self.__show_settings_dialog()

  def __show_settings_dialog(self, button=None):
    self.__config.load()
    settings_dialog = gtk.Dialog(self.app_name, None, 
                                 gtk.DIALOG_MODAL | gtk.DIALOG_NO_SEPARATOR, 
                                 self.__config_ui.get_dialog_buttons())
    wpa = gtk.VBox()
    config_controls = {}
    config_keys = [key for key in self.__config.get_keys() 
                   if key.startswith('settings')]
    config_keys_controls = set(config_keys)
    for iface in self.__interfaces:
      iface_name = iface.get_name()
      iface_key = iface_name.lower()
      wpa.pack_start(gtk.Label('%s' % iface_name))
      iface_keys = set(key for key in config_keys_controls 
                       if key.startswith('settings/%s/' % (iface_key)))
      config_keys_controls -= iface_keys
      iface_keys = list(iface_keys)
      iface_keys.sort()
      for config_key in iface_keys:
        name, ck_type, value = self.__config.get_entry(config_key)
        config_options = self.__config.get_option(config_key)
        options = ()
        if config_options:
          options = zip(map(self.__lcl.get_item, config_options), config_options)
        config_control = self.__config_ui.create_control(self.__lcl.get(config_key.replace('settings/%s/' % (iface_key),'',1)), 
                                                         ck_type, 
                                                         (self.__lcl.get_item(str(value)), 
                                                          value), 
                                                         options)
        if config_control:
          config_controls[config_key] = config_control
          wpa.pack_start(config_control, False)
    if config_keys_controls:
      wpa.pack_start(gtk.Label(self.__lcl.get('settings-other')))
      for config_key in config_keys_controls:
        name, ck_type, value = self.__config.get_entry(config_key)
        config_options = self.__config.get_option(config_key)
        options = ()
        if config_options:
          options = zip(map(self.__lcl.get, config_options), config_options)
        config_control = self.__config_ui.create_control(self.__lcl.get(config_key), 
                                                         ck_type, 
                                                         (self.__lcl.get_item(str(value)), 
                                                          value), 
                                                         options)
        if config_control:
          config_controls[config_key] = config_control
          wpa.pack_start(config_control, False)
    about_page = gtk.VBox()
    about_page.pack_start(gtk.Label('%s %s' % (self.app_name, self.version)))
    about_page.pack_start(gtk.Label('%s%s %s <%s>' % (u'\u00A9', 
                                                      self.dev_years, 
                                                      self.dev_author, 
                                                      self.dev_email)))
    notebook = NotebookMaemo5()
    notebook.set_box(settings_dialog.vbox)
    notebook.append_pages(([[self.__gtk_swr.get_text(gtk.STOCK_PREFERENCES), 
                             wpa], 
                            [self.__gtk_swr.get_text(gtk.STOCK_ABOUT), 
                             about_page]]))
#    settings_dialog.vbox.set_size_request(-1, min(350, notebook.get_height()))
    settings_dialog.show_all()
    notebook.set_active(0)
    response = settings_dialog.run()

    if response == gtk.RESPONSE_OK:
      controls_keys = config_controls.keys()
      for config_key in config_keys:
        if config_key in controls_keys:
          name, ck_type, value = self.__config.get_entry(config_key)
          value = self.__config_ui.get_value(config_controls[config_key], 
                                             value, ck_type)
          self.__config.set_value(config_key, value)
      self.__config.save()
    settings_dialog.destroy()

  def process_sai(self, iname, image='', add=True):
    if add:
      try:
        self.__sai_animator.remove_image(self.__animation_images[iname])
      except:
        pass
      self.__animation_images[iname] = image
      self.__sai_animator.add_image(image)
    else:
      try:
        image = self.__animation_images[iname]
        self.__sai_animator.remove_image(image)
      except:
        pass

  def __set_sai(self, key):
    self.set_status_area_icon(self.__sai_cacher.get(key))

def get_hd_plugin_type(): return AdvancedInterfaceSwitcherMaemo5
